Struct
QmiMessagePbmGetEmergencyListOutput
since: 1.38
Description [src]
struct QmiMessagePbmGetEmergencyListOutput {
/* No available fields */
}
The QmiMessagePbmGetEmergencyListOutput structure contains private data and should only be accessed
using the provided API.
Available since: 1.38
Instance methods
qmi_message_pbm_get_emergency_list_output_get_card_numbers
Get the ‘Card Numbers’ field from self.
since: 1.38
qmi_message_pbm_get_emergency_list_output_get_card_numbers_gir
Get the ‘Card Numbers’ field from self.
since: 1.38
qmi_message_pbm_get_emergency_list_output_get_hardcoded_numbers
Get the ‘Hardcoded Numbers’ field from self.
since: 1.38
qmi_message_pbm_get_emergency_list_output_get_network_numbers
Get the ‘Network Numbers’ field from self.
since: 1.38
qmi_message_pbm_get_emergency_list_output_get_network_numbers_gir
Get the ‘Network Numbers’ field from self.
since: 1.38
qmi_message_pbm_get_emergency_list_output_get_nv_numbers
Get the ‘NV Numbers’ field from self.
since: 1.38
qmi_message_pbm_get_emergency_list_output_get_result
Get the result of the QMI operation.
since: 1.38
qmi_message_pbm_get_emergency_list_output_ref
Atomically increments the reference count of self by one.
since: 1.38
qmi_message_pbm_get_emergency_list_output_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.38